@@ -21,34 +21,21 @@ QwtPlotItem
 
 import math
 
-from qtpy.QtWidgets import (
-    QWidget,
-    QSizePolicy,
-    QFrame,
-    QApplication,
-)
-from qtpy.QtGui import QFont, QPainter, QPalette, QColor, QBrush
-from qtpy.QtCore import Qt, Signal, QEvent, QSize, QRectF
+import numpy as np
+from qtpy.QtCore import QEvent, QRectF, QSize, Qt, Signal
+from qtpy.QtGui import QBrush, QColor, QFont, QPainter, QPalette
+from qtpy.QtWidgets import QApplication, QFrame, QSizePolicy, QWidget
 
-from qwt.text import QwtText, QwtTextLabel
-from qwt.scale_widget import QwtScaleWidget
-from qwt.scale_draw import QwtScaleDraw
-from qwt.scale_engine import QwtLinearScaleEngine
+from qwt.graphic import QwtGraphic
+from qwt.interval import QwtInterval
+from qwt.legend import QwtLegendData
 from qwt.plot_canvas import QwtPlotCanvas
 from qwt.scale_div import QwtScaleDiv
+from qwt.scale_draw import QwtScaleDraw
+from qwt.scale_engine import QwtLinearScaleEngine
 from qwt.scale_map import QwtScaleMap
-from qwt.graphic import QwtGraphic
-from qwt.legend import QwtLegendData
-from qwt.interval import QwtInterval
-
-import numpy as np
-
-
-def qwtEnableLegendItems(plot, on):
-    if on:
-        plot.legendDataChanged.connect(plot.updateLegendItems)
-    else:
-        plot.legendDataChanged.disconnect(plot.updateLegendItems)
+from qwt.scale_widget import QwtScaleWidget
+from qwt.text import QwtText, QwtTextLabel
 
 
 def qwtSetTabOrder(first, second, with_children):
@@ -88,111 +75,10 @@ class ItemList(list):
         self.sortItems()
 
 
-class QwtPlotDict_PrivateData(object):
-    def __init__(self):
-        self.itemList = ItemList()
-        self.autoDelete = True
-
-
-class QwtPlotDict(object):
-    """
-    A dictionary for plot items
-
-    `QwtPlotDict` organizes plot items in increasing z-order.
-    If `autoDelete()` is enabled, all attached items will be deleted
-    in the destructor of the dictionary.
-    `QwtPlotDict` can be used to get access to all `QwtPlotItem` items - or
-    all items of a specific type -  that are currently on the plot.
-
-    .. seealso::
-
-        :py:meth:`QwtPlotItem.attach()`, :py:meth:`QwtPlotItem.detach()`,
-        :py:meth:`QwtPlotItem.z()`
-    """
-
-    def __init__(self):
-        self.__data = QwtPlotDict_PrivateData()
-
-    def setAutoDelete(self, autoDelete):
-        """
-        En/Disable Auto deletion
-
-        If Auto deletion is on all attached plot items will be deleted
-        in the destructor of `QwtPlotDict`. The default value is on.
-
-        :param bool autoDelete: enable/disable
-
-        .. seealso::
-
-            :py:meth:`autoDelete()`, :py:meth:`insertItem()`
-        """
-        self.__data.autoDelete = autoDelete
-
-    def autoDelete(self):
-        """
-        :return: true if auto deletion is enabled
-
-        .. seealso::
-
-            :py:meth:`setAutoDelete()`, :py:meth:`insertItem()`
-        """
-        return self.__data.autoDelete
-
-    def insertItem(self, item):
-        """
-        Insert a plot item
-
-        :param qwt.plot.QwtPlotItem item: PlotItem
-
-        .. seealso::
-
-            :py:meth:`removeItem()`
-        """
-        self.__data.itemList.insertItem(item)
-
-    def removeItem(self, item):
-        """
-        Remove a plot item
-
-        :param qwt.plot.QwtPlotItem item: PlotItem
-
-        .. seealso::
-
-            :py:meth:`insertItem()`
-        """
-        self.__data.itemList.removeItem(item)
-
-    def detachItems(self, rtti=None):
-        """
-        Detach items from the dictionary
-
-        :param rtti: In case of `QwtPlotItem.Rtti_PlotItem` or None (default) detach all items otherwise only those items of the type rtti.
-        :type rtti: int or None
-        """
-        for item in self.__data.itemList[:]:
-            if rtti in (None, QwtPlotItem.Rtti_PlotItem) or item.rtti() == rtti:
-                item.attach(None)
-
-    def itemList(self, rtti=None):
-        """
-        A list of attached plot items.
-
-        Use caution when iterating these lists, as removing/detaching an
-        item will invalidate the iterator. Instead you can place pointers
-        to objects to be removed in a removal list, and traverse that list
-        later.
-
-        :param int rtti: In case of `QwtPlotItem.Rtti_PlotItem` detach all items otherwise only those items of the type rtti.
-        :return: List of all attached plot items of a specific type. If rtti is None, return a list of all attached plot items.
-        """
-        if rtti is None or rtti == QwtPlotItem.Rtti_PlotItem:
-            return self.__data.itemList
-        return [item for item in self.__data.itemList if item.rtti() == rtti]
-
-
-class QwtPlot_PrivateData(QwtPlotDict_PrivateData):
+class QwtPlot_PrivateData(object):
     def __init__(self):
         super(QwtPlot_PrivateData, self).__init__()
+        self.itemList = ItemList()
         self.titleLabel = None
         self.footerLabel = None
         self.canvas = None
@@ -217,7 +103,7 @@ class AxisData(object):
         self.scaleWidget = None  # QwtScaleWidget
 
 
-class QwtPlot(QwtPlotDict, QFrame):
+class QwtPlot(QFrame):
     """
     A 2-D plotting widget
 
@@ -300,7 +186,6 @@ class QwtPlot(QwtPlotDict, QFrame):
                 "%s() takes 0, 1 or 2 argument(s) (%s given)"
                 % (self.__class__.__name__, len(args))
             )
-        QwtPlotDict.__init__(self)
         QFrame.__init__(self, parent)
 
         self.__layout_state = None
@@ -359,7 +244,74 @@ class QwtPlot(QwtPlotDict, QFrame):
         for idx in range(len(focusChain) - 1):
             qwtSetTabOrder(focusChain[idx], focusChain[idx + 1], False)
 
-        qwtEnableLegendItems(self, True)
+        self.legendDataChanged.connect(self.updateLegendItems)
+
+    def insertItem(self, item):
+        """
+        Insert a plot item
+
+        :param qwt.plot.QwtPlotItem item: PlotItem
+
+        .. seealso::
+
+            :py:meth:`removeItem()`
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        self.__data.itemList.insertItem(item)
+
+    def removeItem(self, item):
+        """
+        Remove a plot item
+
+        :param qwt.plot.QwtPlotItem item: PlotItem
+
+        .. seealso::
+
+            :py:meth:`insertItem()`
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        self.__data.itemList.removeItem(item)
+
+    def detachItems(self, rtti=None):
+        """
+        Detach items from the dictionary
+
+        :param rtti: In case of `QwtPlotItem.Rtti_PlotItem` or None (default) detach all items otherwise only those items of the type rtti.
+        :type rtti: int or None
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        for item in self.__data.itemList[:]:
+            if rtti in (None, QwtPlotItem.Rtti_PlotItem) or item.rtti() == rtti:
+                item.attach(None)
+
+    def itemList(self, rtti=None):
+        """
+        A list of attached plot items.
+
+        Use caution when iterating these lists, as removing/detaching an
+        item will invalidate the iterator. Instead you can place pointers
+        to objects to be removed in a removal list, and traverse that list
+        later.
+
+        :param int rtti: In case of `QwtPlotItem.Rtti_PlotItem` detach all items otherwise only those items of the type rtti.
+        :return: List of all attached plot items of a specific type. If rtti is None, return a list of all attached plot items.
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        if rtti is None or rtti == QwtPlotItem.Rtti_PlotItem:
+            return self.__data.itemList
+        return [item for item in self.__data.itemList if item.rtti() == rtti]
 
     def setFlatStyle(self, state):
         """
@@ -1573,9 +1525,9 @@ class QwtPlot(QwtPlotDict, QFrame):
                 if self.__data.legend.parent() is not self:
                     self.__data.legend.setParent(self)
 
-                qwtEnableLegendItems(self, False)
+                self.blockSignals(True)
                 self.updateLegend()
-                qwtEnableLegendItems(self, True)
+                self.blockSignals(False)
 
                 lpos = self.__data.layout.legendPosition()
 
@@ -1686,7 +1638,7 @@ class QwtPlot(QwtPlotDict, QFrame):
         renderer.renderTo(self, printer)
 
     def exportTo(
-        self, filename, size=(800, 600), size_mm=None, resolution=72.0, format_=None
+        self, filename, size=(800, 600), size_mm=None, resolution=85, format_=None
     ):
         """
         Export plot to PDF or image file (SVG, PNG, ...)
@@ -1694,7 +1646,7 @@ class QwtPlot(QwtPlotDict, QFrame):
         :param str filename: Filename
         :param tuple size: (width, height) size in pixels
         :param tuple size_mm: (width, height) size in millimeters
-        :param float resolution: Image resolution
+        :param int resolution: Resolution in dots per Inch (dpi)
         :param str format_: File format (PDF, SVG, PNG, ...)
         """
         if size_mm is None:
